Test website

## Various Javascript

On every lines below, you should see written "This is working OK"

01a. Simple inline Javascript with content on "normal" FQDN: This is not working

01b. Simple inline Javascript with content on "special chars" FQDN: This is not working

01c. Simple inline Javascript with content on "normal" FQDN and accentuated path: This is not working

01d. Simple inline Javascript with content on "special chars" FQDN and accentuated path: This is not working

01e. Simple inline Javascript with content on "normal" FQDN and utf-8 char in path: This is not working

01f. Simple inline Javascript with content on "special chars" FQDN and utf-8 char in path: This is not working

01g. Simple inline Javascript with content on "normal" FQDN and improperly escaped accentued char in path: This is not working

01h. Simple inline Javascript with content on "special chars" FQDN andimproperly escaped accentued char in path: This is not working

01i. Simple inline Javascript with content on improperly escaped "special chars" FQDN: This is not working

01j. Simple inline Javascript with content accessed with query parameter: This is not working

01k. Simple inline Javascript with content accessed with query parameter and query value containing an equal sign : This is not working

01l. Simple inline Javascript with content accessed with query parameter and query value containing a percent sign: This is not working

01m. Simple inline Javascript with content URL containing an interogation point sign: This is not working

01n. Simple inline Javascript with content URL containing an interogation point sign and a query parameter: This is not working

01o. Simple inline Javascript with content on "normal" FQDN and improperly escaped utf-8 char in path: This is not working

01p. Simple inline Javascript with content on "special chars" FQDN and improperly escaped utf-8 char in path: This is not working

01q. Simple inline Javascript with content on relative path and improperly escaped utf-8 char in path: This is not working

01r. Simple inline Javascript with content on relative path and exclamation mark in path: This is not working

02a. Simple classic Javascript with simple src: This is not working

02b. Simple classic Javascript with src and exclamation mark in path: This is not working

03. Simple classic Javascript with src and type: This is not working

04. Simple classic Javascript onload: This is not working

05. Simple classic Javascript preload as script: This is not working

06a. Simple module Javascript with src and type - nominal case: This is not working

06b. Simple module Javascript with src and type - unused vars: This is not working

06c. Simple module Javascript with src and type - absolute path: This is not working

06d. Simple module Javascript with src and type - parent path: This is not working

06e. Simple module Javascript with src and type - accentuated path: This is not working

06f. Simple module Javascript with src and type - querystring: This is not working

06g. Simple module Javascript with src and type - querystring with equal sign in value: This is not working

06h. Simple module Javascript with src and type - querystring with percent sign in value: This is not working

06i. Simple module Javascript with src and type - interogation sign in path: This is not working

06j. Simple module Javascript with src and type - interogation sign in path and querystring: This is not working

07. Simple module Javascript with modulepreload: This is not working

08a. Simple module Javascript with importmap required: This is not working

08b. Simple module Javascript with importmap required: This is not working

08c. Simple module Javascript with importmap required: This is not working

09a. Simple module Javascript with importmap required but nasty URL used in JS: This is not working

09b. Simple module Javascript with importmap required but nasty URL used in JS: This is not working

09c. Simple module Javascript with importmap required but nasty URL used in JS: This is not working

09d. Simple module Javascript with importmap required but nasty URL used in JS: This is not working

10. Rewritting image src dynamically based on already statically rewritten link: